Què és OiRA? | OiRA

Temes

# Què és OiRA?

## És la primera vegada que accediu a OiRA?

Aquí trobareu una breu introducció sobre l’avaluació de riscos i com us pot ajudar OiRA a gestionar-la.

En què consisteix l’avaluació de riscos?

L’avaluació de riscos, a més de constituir la base per gestionar d’una manera eficaç la seguretat i la salut, és clau per reduir els accidents de treball i les malalties professionals. Si s’aplica adequadament, pot millorar la seguretat i la salut en els llocs de treball i el rendiment de les empreses en general.

A Europa, la seguretat i la salut dels treballadors s’ha de protegir mitjançant l’avaluació i la gestió dels riscos en el treball. Les empreses tenen l’obligació legal de garantir la seguretat i la salut dels treballadors en tots els aspectes relacionats amb el treball i d’efectuar avaluacions de riscos. Per tant, qualsevol empresa ha de dur a terme una avaluació de riscos i elaborar un pla d’acció. Per fer una avaluació eficaç dels riscos d’un lloc de treball, tots els implicats han de tenir clar:

- El context i els conceptes jurídics.
- El procés utilitzat per avaluar els riscos.
- La funció que tindran els principals agents que intervenen en el procés.

Els treballadors o els seus representants tenen dret a ser consultats sobre els mecanismes per fer l’avaluació de riscos i participar-hi.

Podeu trobar més informació sobre l’avaluació de riscos i sobre la participació dels treballadors o dels seus representants en el procés d’avaluació de riscos a la pàgina web del projecte OiRA.

## Què és l’eina OiRA?

OiRA significa ‘avaluació interactiva de riscos en línia’ (de l’anglès Online Interactive Risk Assessment). Es tracta d’una aplicació web que us permet fer una avaluació de riscos per a la salut i la seguretat del vostre lloc de treball.

## A qui s’adreça OiRA?

Qualsevol persona pot utilitzar OiRA per avaluar els riscos relacionats amb la salut i la seguretat que hi pot haver en el lloc de treball.

No obstant això, l’eina ha estat concebuda per aportar el màxim valor a les empreses més petites. A més, s’ha desenvolupat específicament per ajudar-les a avaluar els riscos en el treball i a elaborar una avaluació de riscos documentada que inclogui un pla d’acció adaptat als requisits del centre de treball.

## Què cal fer?

Completeu diversos passos en el procés d’avaluació de riscos amb OiRA:

- Preparació: algunes eines inclouen preguntes sobre el perfil per adaptar OiRA a les especificitats de cada centre de treball. Quan contesteu les preguntes sobre el perfil, l’eina s’adaptarà a la situació específica corresponent i us mostrarà els mòduls que s’hi poden aplicar.

- Participació: qualsevol avaluació de riscos s’ha de fer amb la participació activa dels treballadors. L’eina us ofereix la possibilitat d’imprimir el text complet de l’avaluació de riscos o bé algunes parts per informar-ne els treballadors i recollir els seus comentaris.

- Identificació de riscos: OiRA us presentarà possibles riscos o problemes de salut i seguretat que podrien plantejar-se al lloc de treball. En respondre les declaracions o preguntes amb un sí o un no, indicareu si aquests perills o problemes existeixen. També podeu deixar una pregunta sense respondre i contestar-la més endavant.

- Avaluació: algunes eines demanen que jerarquitzeu els riscos identificats. Hi ha diferents maneres de fer-ho, en funció de les decisions que hagin adoptat els nostres socis o desenvolupadors nacionals de l’OiRA i del seu enfocament específic. Algunes eines també estableixen automàticament la jerarquització dels riscos en segon pla (podeu modificar aquestes prioritats).

- Pla d’acció: per a cada risc identificat, l’eina us demana que opteu per una o diverses mesures per eliminar-lo o reduir-lo. La majoria de les eines us proposen algunes mesures. També podeu introduir les vostres pròpies mesures.

- Informe: teniu l’obligació legal de documentar la vostra avaluació de riscos. A la secció d’informes trobareu diversos documents que us ajudaran a portar un registre de la vostra avaluació de riscos i fer un seguiment de les accions o mesures que hàgiu decidit aplicar per eliminar o reduir els riscos identificats.

## Quant de temps caldrà?

No es pot determinar el temps que tardareu a fer una avaluació amb caràcter general, ja que les eines varien en funció dels sectors i dels països.

Amb tot, podeu dedicar el temps que tingueu per fer una avaluació i, després, reprendre-la quan calgui des d’on ho vau deixar.

## Per què cal registrar-se?

El primer pas que us demanarà l’aplicació en iniciar la primera avaluació de riscos serà crear un compte a OiRA, un procés senzill i ràpid. En registrar-vos, podeu iniciar sessió en qualsevol moment per continuar amb les avaluacions anteriors o iniciar-ne de noves. Si ja sou usuaris registrats, podeu obtenir una avaluació de riscos impresa, exacta i actualitzada en qualsevol moment.

## Cal preparar alguna cosa?

No cal cap tipus de preparació específica per començar a utilitzar l’eina, però heu de dedicar temps a pensar qui durà a terme l’avaluació de riscos, com participaran els treballadors en el procés, etc.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More